@@ -6,10 +6,7 @@ use Apache::AxKit::Language::XSP::SimpleTaglib;
 use Apache::AxKit::Exception;
 use AxKit;
 use AxKit::App::TABOO::Data::Comment;
-use AxKit::App::TABOO::Data::Plurals::Comments;
-use AxKit::App::TABOO::Data::Story;
-use AxKit::App::TABOO;
-use Session;
+use Apache::AxKit::Plugin::BasicSession;
 use Time::Piece ':override';
 use XML::LibXML;
 
@@ -17,7 +14,7 @@ use XML::LibXML;
 
 use vars qw/$NS/;
 
-our $VERSION = '0.4';
+our $VERSION = '0.093';
 
 =head1 NAME
 
@@ -40,12 +37,9 @@ Add this taglib to AxKit (via httpd.conf or .htaccess):
 
 =head1 DESCRIPTION
 
-This XSP taglib provides a single (for now) tag to store information
-related to news stories, as it communicates with TABOO Data objects,
-particulary L<AxKit::App::TABOO::Data::Comment>.
+This XSP taglib provides a single (for now) tag to store information related to news stories, as it communicates with TABOO Data objects, particulary L<AxKit::App::TABOO::Data::Comment>.
 
-L<Apache::AxKit::Language::XSP::SimpleTaglib> has been used to write
-this taglib.
+L<Apache::AxKit::Language::XSP::SimpleTaglib> has been used to write this taglib.
 
 =cut
 
@@ -91,34 +85,30 @@ namespace with the number 1.
 
 sub store : node({http://www.kjetil.kjernsmo.net/software/TABOO/NS/Comment/Output}store) {
     return << 'EOC'
-    my %args;
-    foreach my $name ($cgi->param) {
-      $args{$name} = $cgi->param($name);
-    }
-    my $session = AxKit::App::TABOO::session($r);
-    $args{'username'} = AxKit::App::TABOO::loggedin($session);
+    my %args = map { $_ => join('', $cgi->param($_)) } $cgi->param;
+    $args{'username'} = $Apache::AxKit::Plugin::BasicSession::session{credential_0};
 
-    my $authlevel = AxKit::App::TABOO::authlevel($session);
+    my $authlevel =  $Apache::AxKit::Plugin::BasicSession::session{authlevel};
     AxKit::Debug(6, "Logged in as $args{'username'} at level $authlevel");
     unless (defined($authlevel)) {
 	throw Apache::AxKit::Exception::Retval(
 					       return_code => AUTH_REQUIRED,
 					       -text => "Not authenticated and authorized with an authlevel");
     }
-    my $check = AxKit::App::TABOO::Data::Comment->new();
-    if (($args{'parentcpath'})
-	 && (!$check->exist(storyname => $args{'storyname'}, 
-			    sectionid => $args{'sectionid'},
-			    commentpath => $args{'parentcpath'}))) {
-      # This is actually bad, it shouldn't ever happen
-      throw Apache::AxKit::Exception::Retval(
-					     return_code => FORBIDDEN,
-					     -text => "The parent post of the submitter doesn't exist.");
-    }
+    
+#    if ($authlevel < 0) {
+#      throw Apache::AxKit::Exception::Retval(
+#					     return_code => FORBIDDEN,
+#					     -text => ". Your level: " . $authlevel);
+#    }
+
+    my $comment = AxKit::App::TABOO::Data::Comment->new();
+
     my $timestamp = localtime;
     unless ($args{'timestamp'}) {
 	$args{'timestamp'} = $timestamp->datetime;
     }
+    
     $args{'commentpath'} = $args{'parentcpath'} . '/' . $args{'username'};
     my $check = AxKit::App::TABOO::Data::Plurals::Comments->new();
     my $exists = $check->exist(storyname => $args{'storyname'}, 
@@ -129,16 +119,8 @@ sub store : node({http://www.kjetil.kjernsmo.net/software/TABOO/NS/Comment/Outpu
     }
     delete $args{'parentcpath'};
 
-    my $comment = AxKit::App::TABOO::Data::Comment->new();
     $comment->populate(\%args);
     $comment->save();
-    # Modify the last timestamp of the parent story
-    my $story = AxKit::App::TABOO::Data::Story->new();
-    $story->load(what => 'storyname,sectionid',
-		 limit => {storyname => $args{'storyname'},
-			   sectionid => $args{'sectionid'}});
-    $story->lasttimestamp($timestamp);
-    $story->save;
     1;
 EOC
 }
@@ -154,11 +136,11 @@ useful for previewing a submission.
 
 sub this_comment : struct {
     return << 'EOC'
-    my %args;
-    foreach my $name ($cgi->param) {
-      $args{$name} = $cgi->param($name);
-    }
-    $args{'username'} = AxKit::App::TABOO::loggedin(AxKit::App::TABOO::session($r));
+	my %args = map { $_ => $cgi->param($_) } $cgi->param;
+ 
+
+    $args{'username'} = $Apache::AxKit::Plugin::BasicSession::session{credential_0};
+
     my $timestamp = localtime;
     unless ($args{'timestamp'}) {
 	$args{'timestamp'} = $timestamp->datetime;
